<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Remejy Base Theme
 */

if ( ! function_exists( 'remejy_wp_base_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function remejy_wp_base_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	
	/* -- 9/7/15 hid this line as i did not want both the original publish time and updated time. only need the updated time above
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}*/

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	/* original code that put link of page to time. dont need link, change to version after this
	$posted_on = sprintf(
		esc_html_x( 'Posted on %s', 'post date', 'remejy_wp_base' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);*/
	
	$posted_on = sprintf(
		esc_html_x( 'Posted on %s', 'post date', 'remejy_wp_base' ),
		$time_string
	);

	/* don't want link to author either, so created new version below this
	$byline = sprintf(
		esc_html_x( 'by %s', 'post author', 'remejy_wp_base' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);*/
	
	$byline = sprintf(
		esc_html_x( 'by %s', 'post author', 'remejy_wp_base' ),
		'<span class="author">' . esc_html( get_the_author() ) . '</span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'remejy_wp_base_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function remejy_wp_base_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'remejy_wp_base' ) );
		if ( $categories_list && remejy_wp_base_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'remejy_wp_base' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'remejy_wp_base' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'remejy_wp_base' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'remejy_wp_base' ), esc_html__( '1 Comment', 'remejy_wp_base' ), esc_html__( '% Comments', 'remejy_wp_base' ) );
		echo '</span>';
	}

	edit_post_link( esc_html__( 'Edit', 'remejy_wp_base' ), '<span class="edit-link">', '</span>' );
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function remejy_wp_base_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'remejy_wp_base_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'remejy_wp_base_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so remejy_wp_base_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so remejy_wp_base_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in remejy_wp_base_categorized_blog.
 */
function remejy_wp_base_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'remejy_wp_base_categories' );
}
add_action( 'edit_category', 'remejy_wp_base_category_transient_flusher' );
add_action( 'save_post',     'remejy_wp_base_category_transient_flusher' );
